@@ -1,13 +1,14 @@
 # miscellaneous soil color indices
 
 #' @title Horizon Color Indices
-#' @description Calculate basic horizon-level color indices for a SoilProfileCollection. Basic indices do not require aggregation over the whole profile or comparison to a "reference" (e.g. parent material) color. Includes Hurst (1977) Redness Index, Barron-Torrent Redness Index (1986) and Buntley-Westin Index (1965).
+#' @description Calculate basic horizon-level color indices for a SoilProfileCollection. Basic indices do not require aggregation over the whole profile or comparison to a "reference" (e.g. parent material) color. Includes Hurst (1977) Redness Index, Barron-Torrent Redness Index (1986) and Buntley-Westin Index (1965). This is a wrapper method around several horizon-level indices. See the individual functions for more details.
 #' @param p A SoilProfileCollection
 #' @param hue Column name containing moist hue; default: "m_hue"
 #' @param value Column name containing moist value; default: "m_value"
 #' @param chroma Column name containing moist chroma; default: "m_chroma"
 #' @return A data.frame containing unique pedon and horizon IDs and horizon-level color indices.
 #' @author Andrew G. Brown.
+#' @seealso \code{\link{hurst.redness}} \code{\link{barron.torrent.redness.LAB}} \code{\link{buntley.westin.index}}
 #' @examples
 #' data(sp1)
 #'
@@ -47,6 +48,7 @@ horizonColorIndices <- function(p, hue="m_hue", value="m_value", chroma="m_chrom
 #' @param chroma A numeric vector containing Munsell chromas
 #' @return A numeric vector of horizon redness index (lower values = redder).
 #' @author Andrew G. Brown.
+#' @references Hurst, V.J. (1977) Visual estimation of iron in saprolite. GSA Bulletin. 88(2): 174–176. doi: https://doi.org/10.1130/0016-7606(1977)88<174:VEOIIS>2.0.CO;2
 #' @rdname hurst.redness
 #' @export hurst.redness
 hurst.redness <-  function(hue, value, chroma) {
@@ -66,6 +68,7 @@ hurst.redness <-  function(hue, value, chroma) {
 #' @param chroma A numeric vector containing Munsell chromas
 #' @return A numeric vector of horizon redness index (higher values = redder).
 #' @author Andrew G. Brown.
+#' @references Barron, V. and Torrent, J. (1986), Use of the Kubelka—Munk theory to study the influence of iron oxides on soil colour. Journal of Soil Science, 37: 499-510. doi:10.1111/j.1365-2389.1986.tb00382.x
 #' @rdname barron.torrent.redness.LAB
 #' @export barron.torrent.redness.LAB
 barron.torrent.redness.LAB <- function(hue, value, chroma) {
@@ -76,33 +79,146 @@ barron.torrent.redness.LAB <- function(hue, value, chroma) {
 }
 
 #' @title Harden (1982) Rubification
-#' @description Calculate Rubification component of Profile Development Index after Harden (1982) "A quantitative index of soil development from field descriptions: Examples from a chronosequence in central California". Accepts vectorized inputs for hue, value and chroma to produce vector output. In Harden (1982) rubification is calculated relative to a reference parent material. Several other non-color components are normalized relative to a maximum value and summed to obtain the overall Profile Development Index.
+#' @description Calculate Rubification component of Profile Development Index after Harden (1982) "A quantitative index of soil development from field descriptions: Examples from a chronosequence in central California". Accepts vectorized inputs for hue and chroma to produce vector output.
+#'
+#' In Harden (1982) rubification is calculated relative to a reference parent material. Several other non-color components are normalized relative to a maximum value and summed to obtain the overall Profile Development Index.
+#'
 #' @param hue A character vector containing Munsell hues (e.g. "7.5YR")
-#' @param chroma A numeric vector containingMunsell chromas
+#' @param chroma A numeric vector containing Munsell chromas
 #' @param hue_ref A character vector containing Munsell hue(s) (e.g. "10YR") for reference material
 #' @param chroma_ref A numeric vector containing Munsell chroma(s) for reference material
 #' @return A numeric vector reflecting horizon redness increase relative to a reference (e.g. parent) material.
-#' @author Andrew G. Brown.
+#' @author Andrew G. Brown
+#' @references Harden, J.W. (1982) A quantitative index of soil development from field descriptions: Examples from a chronosequence in central California. Geoderma. 28(1) 1-28. doi:  10.1016/0016-7061(82)90037-4
 #' @rdname harden.rubification
 #' @export harden.rubification
+#' @examples
+#' library(aqp)
+#' data("jacobs2000", package="aqp")
+#'
+#' # LEFT JOIN hue, value, chroma matrix color columns
+#' horizons(jacobs2000) <- cbind(horizons(jacobs2000)[,c(idname(jacobs2000), hzidname(jacobs2000))],
+#'                               parseMunsell(jacobs2000$matrix_color_munsell, convertColors = FALSE))
+#'
+#' #' # calculate a mixed 150-200cm color ~"parent material"
+#' jacobs2000$c_horizon_color <- profileApply(jacobs2000, function(p) {
+#'
+#'   # and derive the parent material from the 150-200cm interval
+#'   p150_200 <- glom(p, 150, 200, truncate = TRUE)
+#'   p150_200$thickness <- p150_200$bottom - p150_200$top
+#'   # mix colors
+#'   clrs <- na.omit(horizons(p150_200)[,c('matrix_color_munsell','thickness')])
+#'   mixMunsell(clrs$matrix_color_munsell, w = clrs$thickness)$munsell
+#' })
+#'
+#' # segment profile into 1cm slices (for proper depth weighting)
+#' jacobs2000$rubif <- profileApply(jacobs2000, function(p) {
+#'
+#'   # sum the melanization index over the 0-100cm interval
+#'   p0_100 <- segment(p, 0:100)
+#'
+#'   ccol <- parseMunsell(p$c_horizon_color, convertColors = FALSE)
+#'
+#'   sum(harden.rubification(
+#'     hue = p0_100$hue,
+#'     chroma = as.numeric(p0_100$chroma),
+#'     hue_ref = ccol$hue,
+#'     chroma_ref = as.numeric(ccol$chroma)
+#'   ), na.rm = TRUE)
+#'
+#' })
+#'
+#' jacobs2000$rubiforder <- order(jacobs2000$rubif)
+#'
+#' # Plot in order of increasing Rubification index
+#'
+#' plotSPC(jacobs2000, axis.line.offset = -1,
+#'         color = "matrix_color",
+#'         label = "rubif",
+#'         plot.order = jacobs2000$rubiforder)
+#'
+#' abline(h = c(0,100,150,200), lty = 2)
+#'
+#' # Add [estimated] parent material color swatches
+#' lapply(seq_along(jacobs2000$c_horizon_color), function(i) {
+#'   rect(i - 0.15, 250, i + 0.15, 225,
+#'        col = parseMunsell(jacobs2000$c_horizon_color[jacobs2000$rubiforder[i]]))
+#' })
 harden.rubification <- function(hue, chroma, hue_ref, chroma_ref) {
   # after Harden (1982)  "A quantitative index of soil development from field descriptions:
   #                       Examples from a chronosequence in central California"
-  hue.lookup.table <- 8:0
+  hue.lookup.table <- 0:8
   names(hue.lookup.table) <- c('5R','7.5R','10R','2.5YR','5YR','7.5YR','10YR','2.5Y')
-  dH <- as.numeric(hue.lookup.table[hue] - hue.lookup.table[hue_ref])
+  dH <- -as.numeric(hue.lookup.table[hue] - hue.lookup.table[hue_ref])
   dC <- chroma - chroma_ref
   return(10 * (dH + dC))
 }
 
 #' @title Harden (1982) Melanization
-#' @description Calculate Melanization component of Profile Development Index after Harden (1982) "A quantitative index of soil development from field descriptions: Examples from a chronosequence in central California". Accepts vectorized inputs for hue and chroma to produce vector output. In Harden (1982), melanization is calculated relative to a reference parent material for all horizons within 100cm of the soil surface. In addition, several other non-color components are normalized relative to a maximum value and summed to obtain the overall Profile Development Index.
+#'
+#' @description Calculate Melanization component of Profile Development Index after Harden (1982) "A quantitative index of soil development from field descriptions: Examples from a chronosequence in central California". Accepts vectorized inputs for value and reference value to produce vector output. A convenient use case would be to apply this on a profile-specific basis, where the `value_ref` has a single value, and `value` is a vector of length equal to the number of horizons within the upper 100 cm.
+#'
+#' @details In Harden (1982), melanization is calculated relative to a reference parent material for all horizons within 100cm of the soil surface. In addition, several other non-color components are normalized relative to a maximum value and summed to obtain the overall Profile Development Index.
+#'
 #' @param value numeric vector containing Munsell values
 #' @param value_ref A numeric vector containingMunsell value(s) for reference material
 #' @return A numeric vector reflecting horizon darkening relative to a reference (e.g. parent) material.
 #' @author Andrew G. Brown.
+#' @references Harden, J.W. (1982) A quantitative index of soil development from field descriptions: Examples from a chronosequence in central California. Geoderma. 28(1) 1-28. doi:  10.1016/0016-7061(82)90037-4
 #' @rdname harden.melanization
 #' @export harden.melanization
+#' @examples
+#' library(aqp)
+#' data("jacobs2000", package="aqp")
+#'
+#' # LEFT JOIN hue, value, chroma matrix color columns
+#' horizons(jacobs2000) <- cbind(horizons(jacobs2000)[,c(idname(jacobs2000), hzidname(jacobs2000))],
+#'                               parseMunsell(jacobs2000$matrix_color_munsell, convertColors = FALSE))
+#'
+#' # calculate a mixed 150-200cm color ~"parent material"
+#'
+#' jacobs2000$c_horizon_color <- profileApply(jacobs2000, function(p) {
+#'
+#'   # and derive the parent material from the 150-200cm interval
+#'   p150_200 <- glom(p, 150, 200, truncate = TRUE)
+#'   p150_200$thickness <- p150_200$bottom - p150_200$top
+#'
+#'   # mix colors
+#'   clrs <- na.omit(horizons(p150_200)[,c('matrix_color_munsell','thickness')])
+#'   mixMunsell(clrs$matrix_color_munsell, w = clrs$thickness)$munsell
+#'
+#' })
+#'
+#' # segment profile into 1cm slices (for proper depth weighting)
+#' jacobs2000$melan <- profileApply(jacobs2000, function(p) {
+#'
+#'   # sum the melanization index over the 0-100cm interval
+#'   p0_100 <- segment(p, 0:100)
+#'
+#'   ccol <- parseMunsell(p$c_horizon_color, convertColors = FALSE)
+#'
+#'   sum(harden.melanization(
+#'     value = as.numeric(p0_100$value),
+#'     value_ref = as.numeric(ccol$value)), na.rm = TRUE)
+#'
+#' })
+#'
+#' jacobs2000$melanorder <- order(jacobs2000$melan)
+#'
+#' # Plot in order of increasing Melanization index
+#'
+#' plotSPC(jacobs2000, axis.line.offset = -1,
+#'         color = "matrix_color",
+#'         label = "melan",
+#'         plot.order = jacobs2000$melanorder)
+#'
+#' abline(h = c(0,100,150,200), lty = 2)
+#'
+#' # Add [estimated] parent material color swatches
+#' lapply(seq_along(jacobs2000$c_horizon_color), function(i) {
+#'   rect(i - 0.15, 250, i + 0.15, 225,
+#'        col = parseMunsell(jacobs2000$c_horizon_color[jacobs2000$melanorder[i]]))
+#' })
 harden.melanization <- function(value, value_ref) {
   # for horizons within 100cm of soil surface
   # after Harden (1982)  "A quantitative index of soil development from field descriptions:
@@ -115,8 +231,9 @@ harden.melanization <- function(value, value_ref) {
 #' @description Calculate "Color Development Equivalent" by the method of Buntley & Westin (1965) "A Comparative Study of Developmental Color in a Chestnut-Chernozem-Brunizem Soil Climosequence" DOI: 10.2136/sssaj1965.03615995002900050029x. Originally developed for Mollisols, the Buntley-Westin index has been used as a tool to separate soils based on depth to particular colors.
 #' @param hue A character vector containing Munsell hues (e.g. "7.5YR")
 #' @param chroma A numeric vector containing Munsell chromas
-#' @return A numeric vector reflecting horizon redness (higher values = redder).
+#' @return A numeric vector reflecting horizon color development.
 #' @author Andrew G. Brown.
+#' @references Buntley, G.J. and Westin, F.C. (1965), A Comparative Study of Developmental Color in a Chestnut-Chernozem-Brunizem Soil Climosequence. Soil Science Society of America Journal, 29: 579-582. doi:10.2136/sssaj1965.03615995002900050029x
 #' @rdname buntley.westin.index
 #' @export buntley.westin.index
 buntley.westin.index <- function(hue, chroma) {
@@ -135,8 +252,9 @@ buntley.westin.index <- function(hue, chroma) {
 #' @param pattern Regular expression to match A horizons (default: "^A" which means horizon designation _starts with_ A)
 #' @param value Column name containing horizon color values (default: "m_value")
 #' @param chroma Column name containing horizon color chromas (default: "m_chroma")
-#' @return A numeric vector reflecting horizon redness (higher values = redder).
+#' @return A numeric vector reflecting horizon darkness (lower values = darker).
 #' @author Andrew G. Brown.
+#' @references Thompson, J.A. and Bell, J.C. (1996), Color Index for Identifying Hydric Conditions for Seasonally Saturated Mollisols in Minnesota. Soil Science Society of America Journal, 60: 1979-1988. doi:10.2136/sssaj1996.03615995006000060051x
 #' @rdname thompson.bell.darkness
 #' @export thompson.bell.darkness
 thompson.bell.darkness <- function(p, name = NULL, pattern="^A", value="m_value", chroma="m_chroma") {
